@@ -17,7 +17,7 @@
 
 /*
 ** door_info.c
-** Jason Lango <jal@cs.brown.edu>
+** Jason Lango <jal@rampant.org>
 */
 
 #include <errno.h>
@@ -33,7 +33,7 @@ int __door_info(int d, struct door_info *info)
 	DOOR_INIT();
 
 	args.fd = d;
-	args.info = info;
+	args.info = DOOR_PTR(info);
 
 	return ioctl(__door_dev_fd, DOOR_INFO, &args);
 }
