@@ -17,7 +17,7 @@
 
 /*
 ** door_call.c
-** Jason Lango <jal@cs.brown.edu>
+** Jason Lango <jal@rampant.org>
 */
 
 #include <errno.h>
@@ -28,14 +28,31 @@
 
 int __door_call(int d, door_arg_t *params)
 {
-	struct door_call_args args;
+  struct door_call_args   args;
+  door_karg_t             rparams;
+  int                     error;
 
-	DOOR_INIT();
+  DOOR_INIT();
 
-	args.fd = d;
-	args.params = *params;
-	args.rparams = params;
+  args.fd = d;
+  args.rparams = DOOR_PTR(&rparams);
 
-	return __ioctl(__door_dev_fd, DOOR_CALL, &args);
+  args.params.data_ptr = DOOR_PTR(params->data_ptr);
+  args.params.data_size = params->data_size;
+  args.params.desc_ptr = DOOR_PTR(params->desc_ptr);
+  args.params.desc_num = params->desc_num;
+  args.params.rbuf = DOOR_PTR(params->rbuf);
+  args.params.rsize = params->rsize;
+
+  error = __ioctl (__door_dev_fd, DOOR_CALL, &args);
+
+  if (!error) {
+    params->data_ptr = (char*)DOOR_UINTPTR(rparams.data_ptr);
+    params->data_size = rparams.data_size;
+    params->desc_ptr = (door_desc_t*)DOOR_UINTPTR(rparams.desc_ptr);
+    params->desc_num = rparams.desc_num;
+    params->rbuf = (char*)DOOR_UINTPTR(rparams.rbuf);
+    params->rsize = rparams.rsize;
+  }
+  return error;
 }
-
