@@ -17,7 +17,7 @@
 
 /*
 ** np_door_fattach.c
-** Jason Lango <jal@cs.brown.edu>
+** Jason Lango <jal@rampant.org>
 */
 
 #include "door.h"
@@ -26,16 +26,17 @@
 #include <errno.h>
 #include <sys/ioctl.h>
 
-int __np_door_fattach(int d, const char *name)
+int
+__np_door_fattach (int d, const char *name)
 {
-	struct door_fattach_args args;
+  struct door_fattach_args args;
 
-	DOOR_INIT();
+  DOOR_INIT();
 
-	args.fd = d;
-	args.name = name;
+  args.fd = d;
+  args.name = DOOR_PTR(name);
 
-	return ioctl(__door_dev_fd, DOOR_FATTACH, &args);
+  return ioctl (__door_dev_fd, DOOR_FATTACH, &args);
 }
 
 weak_alias(__np_door_fattach, np_door_fattach)
