@@ -17,7 +17,7 @@
 
 /*
 ** np_door_fdetach.c
-** Jason Lango <jal@cs.brown.edu>
+** Jason Lango <jal@rampant.org>
 */
 
 #include "door.h"
@@ -26,15 +26,16 @@
 #include <errno.h>
 #include <sys/ioctl.h>
 
-int __np_door_fdetach(const char *name)
+int
+__np_door_fdetach (const char *name)
 {
-	struct door_fdetach_args args;
+  struct door_fdetach_args args;
 
-	DOOR_INIT();
+  DOOR_INIT();
 
-	args.name = name;
+  args.name = DOOR_PTR(name);
 
-	return ioctl(__door_dev_fd, DOOR_FDETACH, &args);
+  return ioctl (__door_dev_fd, DOOR_FDETACH, &args);
 }
 
 weak_alias(__np_door_fdetach, np_door_fdetach)
